# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkspace.proto\x12\tworkspace\x1a\x0evalidate.proto\"\x97\x02\n\tWorkspace\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04logo\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bis_personal\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x17\n\ncreated_at\x18\x07 \x01(\tH\x06\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x07\n\x05_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x0e\n\x0c_is_personalB\r\n\x0b_created_at\"\xa9\x01\n\x0fWorkspaceUpdate\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04logo\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_nameB\x07\n\x05_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_color\"\xb8\x02\n\rWorkspaceUser\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12.\n\x04role\x18\x03 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x02\x88\x01\x01\x12\x35\n\x06status\x18\x04 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x03\x88\x01\x01\x12\x16\n\tcreate_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tupdate_at\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x07\n\x05_roleB\t\n\x07_statusB\x0c\n\n_create_atB\x0c\n\n_update_at\"\x90\x01\n\x13WorkspaceUserUpdate\x12.\n\x04role\x18\x01 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x00\x88\x01\x01\x12\x35\n\x06status\x18\x02 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x01\x88\x01\x01\x42\x07\n\x05_roleB\t\n\x07_status\"\xb1\x01\n\x0fWorkspacePlugin\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tcreate_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x05\n\x03_idB\x0f\n\r_workspace_idB\n\n\x08_payloadB\x0c\n\n_create_at\"9\n\x15WorkspacePluginUpdate\x12\x14\n\x07payload\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_payload\"q\n\x16WorkspaceResponseError\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x19.workspace.WorkspaceErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"B\n\x14WorkspaceListRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\n\n\x08_user_id\"\x82\x01\n\x15WorkspaceListResponse\x12(\n\nworkspaces\x18\x01 \x03(\x0b\x32\x14.workspace.Workspace\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x86\x02\n\x16WorkspaceCreateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04logo\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bis_personal\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\n\n\x08_user_idB\x07\n\x05_nameB\x07\n\x05_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x0e\n\x0c_is_personal\"\x96\x01\n\x17WorkspaceCreateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"w\n\x13WorkspaceGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\x93\x01\n\x14WorkspaceGetResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"\x90\x01\n\x16WorkspaceUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x32\n\tworkspace\x18\x02 \x01(\x0b\x32\x1a.workspace.WorkspaceUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_workspace\"\x96\x01\n\x17WorkspaceUpdateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"z\n\x16WorkspaceDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"Z\n\x17WorkspaceDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"P\n\x18WorkspaceUserListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x8f\x01\n\x19WorkspaceUserListResponse\x12\x31\n\x0fworkspace_users\x18\x01 \x03(\x0b\x32\x18.workspace.WorkspaceUser\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"{\n\x17WorkspaceUserGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\xa5\x01\n\x18WorkspaceUserGetResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"\xce\x01\n\x1aWorkspaceUserUpdateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12;\n\x0eworkspace_user\x18\x03 \x01(\x0b\x32\x1e.workspace.WorkspaceUserUpdateH\x02\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x11\n\x0f_workspace_user\"\xa8\x01\n\x1bWorkspaceUserUpdateResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"~\n\x1aWorkspaceUserDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"^\n\x1bWorkspaceUserDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"v\n\x1cWorkspacePluginCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x14\n\x07payload\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\n\n\x08_payload\"\xb0\x01\n\x1dWorkspacePluginCreateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x81\x01\n\x19WorkspacePluginGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"\xad\x01\n\x1aWorkspacePluginGetResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"R\n\x1aWorkspacePluginListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x95\x01\n\x1bWorkspacePluginListResponse\x12\x35\n\x11workspace_plugins\x18\x01 \x03(\x0b\x32\x1a.workspace.WorkspacePlugin\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xda\x01\n\x1cWorkspacePluginUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12?\n\x10workspace_plugin\x18\x03 \x01(\x0b\x32 .workspace.WorkspacePluginUpdateH\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_idB\x13\n\x11_workspace_plugin\"\xb0\x01\n\x1dWorkspacePluginUpdateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x84\x01\n\x1cWorkspacePluginDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"`\n\x1dWorkspacePluginDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error*\x8b\x02\n\x0eWorkspaceError\x12\x16\n\x12WORKSPACE_NO_ERROR\x10\x00\x12\x17\n\x13WORKSPACE_NOT_FOUND\x10\x01\x12!\n\x1dWORKSPACE_USER_ALREADY_EXISTS\x10\x02\x12\x1c\n\x18WORKSPACE_USER_NOT_FOUND\x10\x03\x12!\n\x1dWORKSPACE_USER_ALREADY_ACTIVE\x10\x04\x12(\n$USER_ALREADY_HAVE_PERSONAL_WORKSPACE\x10\x05\x12\x1e\n\x1aWORKSPACE_PLUGIN_NOT_FOUND\x10\x06\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07\x42\x32Z0github.com/jupyter-naas/naas-models/go/workspaceb\x06proto3')

_WORKSPACEERROR = DESCRIPTOR.enum_types_by_name['WorkspaceError']
WorkspaceError = enum_type_wrapper.EnumTypeWrapper(_WORKSPACEERROR)
WORKSPACE_NO_ERROR = 0
WORKSPACE_NOT_FOUND = 1
WORKSPACE_USER_ALREADY_EXISTS = 2
WORKSPACE_USER_NOT_FOUND = 3
WORKSPACE_USER_ALREADY_ACTIVE = 4
USER_ALREADY_HAVE_PERSONAL_WORKSPACE = 5
WORKSPACE_PLUGIN_NOT_FOUND = 6
INTERNAL_SERVER_ERROR = 1000


_WORKSPACE = DESCRIPTOR.message_types_by_name['Workspace']
_WORKSPACEUPDATE = DESCRIPTOR.message_types_by_name['WorkspaceUpdate']
_WORKSPACEUSER = DESCRIPTOR.message_types_by_name['WorkspaceUser']
_WORKSPACEUSERUPDATE = DESCRIPTOR.message_types_by_name['WorkspaceUserUpdate']
_WORKSPACEPLUGIN = DESCRIPTOR.message_types_by_name['WorkspacePlugin']
_WORKSPACEPLUGINUPDATE = DESCRIPTOR.message_types_by_name['WorkspacePluginUpdate']
_WORKSPACERESPONSEERROR = DESCRIPTOR.message_types_by_name['WorkspaceResponseError']
_WORKSPACELISTREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceListRequest']
_WORKSPACELISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceListResponse']
_WORKSPACECREATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceCreateRequest']
_WORKSPACECREATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceCreateResponse']
_WORKSPACEGETREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceGetRequest']
_WORKSPACEGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceGetResponse']
_WORKSPACEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUpdateRequest']
_WORKSPACEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUpdateResponse']
_WORKSPACEDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceDeleteRequest']
_WORKSPACEDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceDeleteResponse']
_WORKSPACEUSERLISTREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUserListRequest']
_WORKSPACEUSERLISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUserListResponse']
_WORKSPACEUSERGETREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUserGetRequest']
_WORKSPACEUSERGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUserGetResponse']
_WORKSPACEUSERUPDATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUserUpdateRequest']
_WORKSPACEUSERUPDATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUserUpdateResponse']
_WORKSPACEUSERDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUserDeleteRequest']
_WORKSPACEUSERDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUserDeleteResponse']
_WORKSPACEPLUGINCREATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginCreateRequest']
_WORKSPACEPLUGINCREATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginCreateResponse']
_WORKSPACEPLUGINGETREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginGetRequest']
_WORKSPACEPLUGINGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginGetResponse']
_WORKSPACEPLUGINLISTREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginListRequest']
_WORKSPACEPLUGINLISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginListResponse']
_WORKSPACEPLUGINUPDATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginUpdateRequest']
_WORKSPACEPLUGINUPDATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginUpdateResponse']
_WORKSPACEPLUGINDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginDeleteRequest']
_WORKSPACEPLUGINDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginDeleteResponse']
Workspace = _reflection.GeneratedProtocolMessageType('Workspace', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.Workspace)
  })
_sym_db.RegisterMessage(Workspace)

WorkspaceUpdate = _reflection.GeneratedProtocolMessageType('WorkspaceUpdate', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUPDATE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUpdate)
  })
_sym_db.RegisterMessage(WorkspaceUpdate)

WorkspaceUser = _reflection.GeneratedProtocolMessageType('WorkspaceUser', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSER,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUser)
  })
_sym_db.RegisterMessage(WorkspaceUser)

WorkspaceUserUpdate = _reflection.GeneratedProtocolMessageType('WorkspaceUserUpdate', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERUPDATE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserUpdate)
  })
_sym_db.RegisterMessage(WorkspaceUserUpdate)

WorkspacePlugin = _reflection.GeneratedProtocolMessageType('WorkspacePlugin', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGIN,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePlugin)
  })
_sym_db.RegisterMessage(WorkspacePlugin)

WorkspacePluginUpdate = _reflection.GeneratedProtocolMessageType('WorkspacePluginUpdate', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINUPDATE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginUpdate)
  })
_sym_db.RegisterMessage(WorkspacePluginUpdate)

WorkspaceResponseError = _reflection.GeneratedProtocolMessageType('WorkspaceResponseError', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACERESPONSEERROR,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceResponseError)
  })
_sym_db.RegisterMessage(WorkspaceResponseError)

WorkspaceListRequest = _reflection.GeneratedProtocolMessageType('WorkspaceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACELISTREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceListRequest)
  })
_sym_db.RegisterMessage(WorkspaceListRequest)

WorkspaceListResponse = _reflection.GeneratedProtocolMessageType('WorkspaceListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACELISTRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceListResponse)
  })
_sym_db.RegisterMessage(WorkspaceListResponse)

WorkspaceCreateRequest = _reflection.GeneratedProtocolMessageType('WorkspaceCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACECREATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceCreateRequest)
  })
_sym_db.RegisterMessage(WorkspaceCreateRequest)

WorkspaceCreateResponse = _reflection.GeneratedProtocolMessageType('WorkspaceCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACECREATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceCreateResponse)
  })
_sym_db.RegisterMessage(WorkspaceCreateResponse)

WorkspaceGetRequest = _reflection.GeneratedProtocolMessageType('WorkspaceGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEGETREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceGetRequest)
  })
_sym_db.RegisterMessage(WorkspaceGetRequest)

WorkspaceGetResponse = _reflection.GeneratedProtocolMessageType('WorkspaceGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEGETRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceGetResponse)
  })
_sym_db.RegisterMessage(WorkspaceGetResponse)

WorkspaceUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUPDATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUpdateRequest)
  })
_sym_db.RegisterMessage(WorkspaceUpdateRequest)

WorkspaceUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUPDATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUpdateResponse)
  })
_sym_db.RegisterMessage(WorkspaceUpdateResponse)

WorkspaceDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkspaceDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEDELETEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceDeleteRequest)
  })
_sym_db.RegisterMessage(WorkspaceDeleteRequest)

WorkspaceDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkspaceDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEDELETERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceDeleteResponse)
  })
_sym_db.RegisterMessage(WorkspaceDeleteResponse)

WorkspaceUserListRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUserListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERLISTREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserListRequest)
  })
_sym_db.RegisterMessage(WorkspaceUserListRequest)

WorkspaceUserListResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUserListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERLISTRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserListResponse)
  })
_sym_db.RegisterMessage(WorkspaceUserListResponse)

WorkspaceUserGetRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUserGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERGETREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserGetRequest)
  })
_sym_db.RegisterMessage(WorkspaceUserGetRequest)

WorkspaceUserGetResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUserGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERGETRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserGetResponse)
  })
_sym_db.RegisterMessage(WorkspaceUserGetResponse)

WorkspaceUserUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUserUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERUPDATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserUpdateRequest)
  })
_sym_db.RegisterMessage(WorkspaceUserUpdateRequest)

WorkspaceUserUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUserUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERUPDATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserUpdateResponse)
  })
_sym_db.RegisterMessage(WorkspaceUserUpdateResponse)

WorkspaceUserDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUserDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERDELETEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserDeleteRequest)
  })
_sym_db.RegisterMessage(WorkspaceUserDeleteRequest)

WorkspaceUserDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUserDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERDELETERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserDeleteResponse)
  })
_sym_db.RegisterMessage(WorkspaceUserDeleteResponse)

WorkspacePluginCreateRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINCREATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginCreateRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginCreateRequest)

WorkspacePluginCreateResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINCREATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginCreateResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginCreateResponse)

WorkspacePluginGetRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINGETREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginGetRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginGetRequest)

WorkspacePluginGetResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINGETRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginGetResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginGetResponse)

WorkspacePluginListRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINLISTREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginListRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginListRequest)

WorkspacePluginListResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINLISTRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginListResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginListResponse)

WorkspacePluginUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINUPDATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginUpdateRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginUpdateRequest)

WorkspacePluginUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINUPDATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginUpdateResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginUpdateResponse)

WorkspacePluginDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINDELETEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginDeleteRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginDeleteRequest)

WorkspacePluginDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINDELETERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginDeleteResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginDeleteResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/jupyter-naas/naas-models/go/workspace'
  _WORKSPACE.fields_by_name['id']._options = None
  _WORKSPACE.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSER.fields_by_name['user_id']._options = None
  _WORKSPACEUSER.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSER.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSER.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSER.fields_by_name['role']._options = None
  _WORKSPACEUSER.fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _WORKSPACEUSER.fields_by_name['status']._options = None
  _WORKSPACEUSER.fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _WORKSPACEUSERUPDATE.fields_by_name['role']._options = None
  _WORKSPACEUSERUPDATE.fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _WORKSPACEUSERUPDATE.fields_by_name['status']._options = None
  _WORKSPACEUSERUPDATE.fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _WORKSPACEPLUGIN.fields_by_name['id']._options = None
  _WORKSPACEPLUGIN.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGIN.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGIN.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACELISTREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACELISTREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACECREATEREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACECREATEREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEGETREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEGETREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEGETREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEGETREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUPDATEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUPDATEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEDELETEREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEDELETEREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEDELETEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEDELETEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERLISTREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSERLISTREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERGETREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEUSERGETREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERGETREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSERGETREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERUPDATEREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEUSERUPDATEREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERUPDATEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSERUPDATEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERDELETEREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEUSERDELETEREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERDELETEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSERDELETEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINCREATEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINCREATEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINGETREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINGETREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINGETREQUEST.fields_by_name['plugin_id']._options = None
  _WORKSPACEPLUGINGETREQUEST.fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINLISTREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINLISTREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINUPDATEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINUPDATEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINUPDATEREQUEST.fields_by_name['plugin_id']._options = None
  _WORKSPACEPLUGINUPDATEREQUEST.fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINDELETEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINDELETEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINDELETEREQUEST.fields_by_name['plugin_id']._options = None
  _WORKSPACEPLUGINDELETEREQUEST.fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEERROR._serialized_start=5324
  _WORKSPACEERROR._serialized_end=5591
  _WORKSPACE._serialized_start=47
  _WORKSPACE._serialized_end=326
  _WORKSPACEUPDATE._serialized_start=329
  _WORKSPACEUPDATE._serialized_end=498
  _WORKSPACEUSER._serialized_start=501
  _WORKSPACEUSER._serialized_end=813
  _WORKSPACEUSERUPDATE._serialized_start=816
  _WORKSPACEUSERUPDATE._serialized_end=960
  _WORKSPACEPLUGIN._serialized_start=963
  _WORKSPACEPLUGIN._serialized_end=1140
  _WORKSPACEPLUGINUPDATE._serialized_start=1142
  _WORKSPACEPLUGINUPDATE._serialized_end=1199
  _WORKSPACERESPONSEERROR._serialized_start=1201
  _WORKSPACERESPONSEERROR._serialized_end=1314
  _WORKSPACELISTREQUEST._serialized_start=1316
  _WORKSPACELISTREQUEST._serialized_end=1382
  _WORKSPACELISTRESPONSE._serialized_start=1385
  _WORKSPACELISTRESPONSE._serialized_end=1515
  _WORKSPACECREATEREQUEST._serialized_start=1518
  _WORKSPACECREATEREQUEST._serialized_end=1780
  _WORKSPACECREATERESPONSE._serialized_start=1783
  _WORKSPACECREATERESPONSE._serialized_end=1933
  _WORKSPACEGETREQUEST._serialized_start=1935
  _WORKSPACEGETREQUEST._serialized_end=2054
  _WORKSPACEGETRESPONSE._serialized_start=2057
  _WORKSPACEGETRESPONSE._serialized_end=2204
  _WORKSPACEUPDATEREQUEST._serialized_start=2207
  _WORKSPACEUPDATEREQUEST._serialized_end=2351
  _WORKSPACEUPDATERESPONSE._serialized_start=2354
  _WORKSPACEUPDATERESPONSE._serialized_end=2504
  _WORKSPACEDELETEREQUEST._serialized_start=2506
  _WORKSPACEDELETEREQUEST._serialized_end=2628
  _WORKSPACEDELETERESPONSE._serialized_start=2630
  _WORKSPACEDELETERESPONSE._serialized_end=2720
  _WORKSPACEUSERLISTREQUEST._serialized_start=2722
  _WORKSPACEUSERLISTREQUEST._serialized_end=2802
  _WORKSPACEUSERLISTRESPONSE._serialized_start=2805
  _WORKSPACEUSERLISTRESPONSE._serialized_end=2948
  _WORKSPACEUSERGETREQUEST._serialized_start=2950
  _WORKSPACEUSERGETREQUEST._serialized_end=3073
  _WORKSPACEUSERGETRESPONSE._serialized_start=3076
  _WORKSPACEUSERGETRESPONSE._serialized_end=3241
  _WORKSPACEUSERUPDATEREQUEST._serialized_start=3244
  _WORKSPACEUSERUPDATEREQUEST._serialized_end=3450
  _WORKSPACEUSERUPDATERESPONSE._serialized_start=3453
  _WORKSPACEUSERUPDATERESPONSE._serialized_end=3621
  _WORKSPACEUSERDELETEREQUEST._serialized_start=3623
  _WORKSPACEUSERDELETEREQUEST._serialized_end=3749
  _WORKSPACEUSERDELETERESPONSE._serialized_start=3751
  _WORKSPACEUSERDELETERESPONSE._serialized_end=3845
  _WORKSPACEPLUGINCREATEREQUEST._serialized_start=3847
  _WORKSPACEPLUGINCREATEREQUEST._serialized_end=3965
  _WORKSPACEPLUGINCREATERESPONSE._serialized_start=3968
  _WORKSPACEPLUGINCREATERESPONSE._serialized_end=4144
  _WORKSPACEPLUGINGETREQUEST._serialized_start=4147
  _WORKSPACEPLUGINGETREQUEST._serialized_end=4276
  _WORKSPACEPLUGINGETRESPONSE._serialized_start=4279
  _WORKSPACEPLUGINGETRESPONSE._serialized_end=4452
  _WORKSPACEPLUGINLISTREQUEST._serialized_start=4454
  _WORKSPACEPLUGINLISTREQUEST._serialized_end=4536
  _WORKSPACEPLUGINLISTRESPONSE._serialized_start=4539
  _WORKSPACEPLUGINLISTRESPONSE._serialized_end=4688
  _WORKSPACEPLUGINUPDATEREQUEST._serialized_start=4691
  _WORKSPACEPLUGINUPDATEREQUEST._serialized_end=4909
  _WORKSPACEPLUGINUPDATERESPONSE._serialized_start=4912
  _WORKSPACEPLUGINUPDATERESPONSE._serialized_end=5088
  _WORKSPACEPLUGINDELETEREQUEST._serialized_start=5091
  _WORKSPACEPLUGINDELETEREQUEST._serialized_end=5223
  _WORKSPACEPLUGINDELETERESPONSE._serialized_start=5225
  _WORKSPACEPLUGINDELETERESPONSE._serialized_end=5321
# @@protoc_insertion_point(module_scope)
